pub enum LightSection {
NotSet,
FullyDark,
FullData(Box<[u8; 2048]>),
}Expand description
Enum describing the light contents of a data section.
We need to differentiate between LightSection::NotSet and
LightSection::FullyDark. This is because, for sky light,
LightSection::NotSet could mean the section is either fully lit or fully
dark, and the client should deduce that from the sky light data that is
included.
Variants
Implementations